"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var keys_1 = require("./helpers/keys");
var plugin_1 = require("stryker-api/plugin");
var BabelConfigReader = /** @class */ (function () {
    function BabelConfigReader(log) {
        this.log = log;
    }
    BabelConfigReader.prototype.readConfig = function (options) {
        var babelConfig = options[keys_1.CONFIG_KEY_OPTIONS] || this.getConfigFile(options) || {};
        this.log.debug("babel config is: " + JSON.stringify(babelConfig, null, 2));
        return babelConfig;
    };
    BabelConfigReader.prototype.getConfigFile = function (options) {
        if (typeof options[keys_1.CONFIG_KEY_FILE] === 'string') {
            var babelrcPath = path.resolve(options[keys_1.CONFIG_KEY_FILE]);
            this.log.info("Reading .babelrc file from path \"" + babelrcPath + "\"");
            if (fs.existsSync(babelrcPath)) {
                try {
                    var config = JSON.parse(fs.readFileSync(babelrcPath, 'utf8'));
                    return config;
                }
                catch (error) {
                    this.log.error("Error while reading .babelrc file: " + error);
                }
            }
            else {
                this.log.error("babelrc file does not exist at: " + babelrcPath);
            }
        }
        else {
            this.log.info("No .babelrc file configured. Please set the \"" + keys_1.CONFIG_KEY_FILE + "\" property in your config.");
        }
        return null;
    };
    BabelConfigReader.inject = plugin_1.tokens(plugin_1.commonTokens.logger);
    return BabelConfigReader;
}());
exports.default = BabelConfigReader;
//# sourceMappingURL=BabelConfigReader.js.map